@@ -18,6 +18,17 @@ public interface NotificationsManager {
 	 * @return true if the notification is correctly delivered, false otherwise
 	 */
 	boolean notifyFolderSharing(String userIdToNotify, WorkspaceFolder sharedFolder) throws Exception;
+	/**
+	 * use to notify a user he got a workspace folder renamed
+	 *
+	 * @param userIdToNotify the user you want to notify
+	 * @param previousName the previous name of the folder
+	 * @param newName the new name of the folder
+	 * @param renamedFolderId the folderId
+	 * @return true if the notification is correctly delivered, false otherwise
+	 */
+	boolean notifyFolderRenaming(String userIdToNotify, String previousName, String newName, String renamedFolderId) throws Exception;
+	/**
 	/**
 	 * use to notify a user that a new user was added in on of his workspace shared folder
 	 *
@@ -32,10 +43,9 @@ public interface NotificationsManager {
 	 *
 	 * @param userIdToNotify the user you want to notify
 	 * @param sharedFolder the shared {@link WorkspaceFolder}  
-	 * @param removedUserId the new user that was removed
 	 * @return true if the notification is correctly delivered, false otherwise
 	 */
-	boolean notifyFolderRemovedUser(String userIdToNotify, WorkspaceFolder sharedFolder, String removedUserId) throws Exception;
+	boolean notifyFolderRemovedUser(String userIdToNotify, WorkspaceFolder sharedFolder) throws Exception;
 	/**
 	 * use to notify a user he got a workspace item new in some of his workspace shared folder
 	 * @param userIdToNotify the user you want to notify
@@ -56,9 +66,10 @@ public interface NotificationsManager {
 	 * use to notify a user he got a workspace item updated from one of his workspace shared folder
 	 * @param userIdToNotify the user you want to notify
 	 * @param updatedItem the updated shared {@link WorkspaceItem}  
+	 * @param sharedFolder the shared folder {@link WorkspaceFolder} 
 	 * @return true if the notification is correctly delivered, false otherwise
 	 */
-	boolean notifyUpdatedItem(String userIdToNotify, WorkspaceItem item) throws Exception;
+	boolean notifyUpdatedItem(String userIdToNotify, WorkspaceItem item, WorkspaceFolder sharedFolder) throws Exception;
 	/**
 	 * 
 	 * @param userIdToNotify the user you want to notify
